# Smart Buildings Dataset

Dataset accompanying  the paper "Real-World Data and
Calibrated Simulation Suite for Offline Training of
Reinforcement Learning Agents to Optimize Energy and
Emission in Office Buildings" by Judah Goldfeder and
John Sipple, containing 6 years of detailed telemetric
readouts from 3 commercial office buildings.